# Generated by roxygen2: do not edit by hand

export(centralValue)
export(dLogLikelihood)
export(importDataSet)
export(knnImputation)
export(nnk)
export(normalDistribution)
export(pgu.corrValidator)
export(pgu.correlator)
export(pgu.data)
export(pgu.delegate)
export(pgu.explorer)
export(pgu.exporter)
export(pgu.file)
export(pgu.filter)
export(pgu.importer)
export(pgu.imputation)
export(pgu.limitsOfQuantification)
export(pgu.missings)
export(pgu.missingsCharacterizer)
export(pgu.model)
export(pgu.normDist)
export(pgu.normalizer)
export(pgu.optimizer)
export(pgu.outliers)
export(pgu.regressor)
export(pgu.reporter)
export(pgu.status)
export(pgu.transformator)
export(pgu.validator)
export(pguIMP)
export(sLogLikelihood)
export(transposeTibble)
importFrom(DT,datatable)
importFrom(DT,formatStyle)
importFrom(DT,renderDataTable)
importFrom(DT,styleEqual)
importFrom(DataVisualizations,ParetoDensityEstimation)
importFrom(Hmisc,rcorr)
importFrom(MASS,boxcox)
importFrom(MASS,fitdistr)
importFrom(R6,R6Class)
importFrom(R6,is.R6)
importFrom(RWeka,M5P)
importFrom(VIM,aggr)
importFrom(bbmle,AIC)
importFrom(bbmle,AICc)
importFrom(bbmle,logLik)
importFrom(bbmle,mle2)
importFrom(bbmle,residuals)
importFrom(bbmle,snorm)
importFrom(dbscan,dbscan)
importFrom(dplyr,add_row)
importFrom(dplyr,all_of)
importFrom(dplyr,any_vars)
importFrom(dplyr,arrange)
importFrom(dplyr,bind_cols)
importFrom(dplyr,bind_rows)
importFrom(dplyr,count)
importFrom(dplyr,everything)
importFrom(dplyr,filter)
importFrom(dplyr,filter_all)
importFrom(dplyr,group_by)
importFrom(dplyr,if_else)
importFrom(dplyr,mutate)
importFrom(dplyr,mutate_all)
importFrom(dplyr,mutate_if)
importFrom(dplyr,n_distinct)
importFrom(dplyr,near)
importFrom(dplyr,pull)
importFrom(dplyr,rename)
importFrom(dplyr,right_join)
importFrom(dplyr,rowwise)
importFrom(dplyr,select)
importFrom(dplyr,select_if)
importFrom(dplyr,slice)
importFrom(dplyr,summarise)
importFrom(dplyr,summarise_all)
importFrom(dplyr,sym)
importFrom(dplyr,transmute_all)
importFrom(dplyr,ungroup)
importFrom(e1071,kurtosis)
importFrom(e1071,skewness)
importFrom(e1071,svm)
importFrom(finalfit,missing_compare)
importFrom(finalfit,missing_pairs)
importFrom(ggplot2,aes)
importFrom(ggplot2,aes_string)
importFrom(ggplot2,coord_flip)
importFrom(ggplot2,element_blank)
importFrom(ggplot2,element_rect)
importFrom(ggplot2,element_text)
importFrom(ggplot2,geom_abline)
importFrom(ggplot2,geom_bar)
importFrom(ggplot2,geom_boxplot)
importFrom(ggplot2,geom_col)
importFrom(ggplot2,geom_histogram)
importFrom(ggplot2,geom_hline)
importFrom(ggplot2,geom_jitter)
importFrom(ggplot2,geom_line)
importFrom(ggplot2,geom_point)
importFrom(ggplot2,geom_smooth)
importFrom(ggplot2,geom_text)
importFrom(ggplot2,geom_vline)
importFrom(ggplot2,ggplot)
importFrom(ggplot2,ggplot_build)
importFrom(ggplot2,ggtitle)
importFrom(ggplot2,layer_scales)
importFrom(ggplot2,scale_linetype_manual)
importFrom(ggplot2,scale_x_continuous)
importFrom(ggplot2,scale_y_continuous)
importFrom(ggplot2,stat_qq)
importFrom(ggplot2,stat_qq_line)
importFrom(ggplot2,stat_smooth)
importFrom(ggplot2,theme)
importFrom(ggplot2,theme_linedraw)
importFrom(ggplot2,xlab)
importFrom(ggplot2,xlim)
importFrom(ggplot2,ylab)
importFrom(ggplot2,ylim)
importFrom(ggthemes,geom_rangeframe)
importFrom(ggthemes,theme_tufte)
importFrom(grid,gpar)
importFrom(grid,textGrob)
importFrom(gridExtra,grid.arrange)
importFrom(magrittr,"%>%")
importFrom(mice,complete)
importFrom(mice,flux)
importFrom(mice,md.pattern)
importFrom(mice,mice)
importFrom(mice,quickpred)
importFrom(nortest,ad.test)
importFrom(nortest,lillie.test)
importFrom(outliers,grubbs.test)
importFrom(psych,describe)
importFrom(purrr,discard)
importFrom(purrr,map)
importFrom(purrr,negate)
importFrom(rcompanion,transformTukey)
importFrom(readr,cols)
importFrom(readr,read_csv)
importFrom(readr,read_delim)
importFrom(readxl,read_xls)
importFrom(readxl,read_xlsx)
importFrom(rlang,sym)
importFrom(rmarkdown,render)
importFrom(robust,lmRob)
importFrom(shiny,Progress)
importFrom(shiny,dialogViewer)
importFrom(shiny,includeHTML)
importFrom(shiny,renderPlot)
importFrom(shiny,renderUI)
importFrom(shiny,runApp)
importFrom(shiny,runGadget)
importFrom(shiny,shinyAppDir)
importFrom(shiny,showNotification)
importFrom(shiny,updateCheckboxInput)
importFrom(shiny,updateNumericInput)
importFrom(shiny,updateSelectInput)
importFrom(stats,BIC)
importFrom(stats,aggregate)
importFrom(stats,as.formula)
importFrom(stats,complete.cases)
importFrom(stats,cor.test)
importFrom(stats,density)
importFrom(stats,dist)
importFrom(stats,dnorm)
importFrom(stats,ks.test)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,optim)
importFrom(stats,quantile)
importFrom(stats,rnorm)
importFrom(stats,shapiro.test)
importFrom(stats,wilcox.test)
importFrom(stringr,str_detect)
importFrom(stringr,str_subset)
importFrom(tibble,add_column)
importFrom(tibble,add_row)
importFrom(tibble,as_tibble)
importFrom(tibble,enframe)
importFrom(tibble,is_tibble)
importFrom(tibble,rownames_to_column)
importFrom(tibble,tibble)
importFrom(tidyr,drop_na)
importFrom(tidyr,expand_grid)
importFrom(tidyr,gather)
importFrom(tidyr,gather_)
importFrom(tidyr,pivot_longer)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
importFrom(tidyr,unite)
importFrom(tidyselect,all_of)
importFrom(tools,file_ext)
importFrom(tools,file_path_sans_ext)
importFrom(writexl,write_xlsx)
