#' Shiny app server object
#'
#' @importFrom shinydashboard dashboardHeader
#'
#' @author Sebastian Malkusch, \email{malkusch@@med.uni-frankfurt.de}
#'
#' @export
#'

# create the shiny application user interface header.

header <- shinydashboard::dashboardHeader(
  title = "PGU IMP"
)
