---
title: "Explore"
output: html_document
---

# Explore Help
Enables graphical uni- as well as bivariate analysis of the data.

## Menu

### Abscissa
Selects the feature to be plotted on the abscissa (x-axis) of the bivariate "Feature Scatter Plot".

### Ordinate
Selects the feature to be plotted on the ordinate (y-axis) of the bivariate "Feature Scatter Plot".

## Analysis

#### Feature Scatter Plot
Bivariate dot plot of the selected features.

### Abscissa Statistics Plot
A univariate graphical analysis of the values of the feature on the abscissa. The analysis requires the selection of a numerical feature. A boxplot is shown with the individual values superimposed as a point cloud. The corresponding distribution of values is shown as a bar chart.

### Abscissa Statistics Table
A table that provides statistical information on the numerical abscissa feature. Included are the minimum value (Min.), the first quantile (1st Qu.), the media, the mean value, the third quartile (3rd Qu.), the maximum value (Max.), the number of missing values (NA's).

### Ordinate Statistics Plot
A univariate graphical analysis of the values of the feature on the ordinate. The analysis requires the selection of a numerical feature. A boxplot is shown with the individual values superimposed as a point cloud. The corresponding distribution of values is shown as a bar chart.

### Ordinate Statistics Table
A table that provides statistical information on the numerical ordinate feature. Included are the minimum value (Min.), the first quantile (1st Qu.), the media, the mean value, the third quartile (3rd Qu.), the maximum value (Max.), the number of missing values (NA's).


